==> apache-geode-1.6.0-src.zip: apache-geode-1.6.0-src/geode-core/src/test/java/org/apache/geode/distributed/internal/deadlock/UnsafeThreadLocalJUnitTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.distributed.internal.deadlock;

import static org.junit.Assert.*;

import java.util.concurrent.CountDownLatch;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.experimental.categories.Category;

import org.apache.geode.test.junit.categories.UnitTest;

@Category(UnitTest.class)
public class UnsafeThreadLocalJUnitTest {

  private static final long INTERVAL = 10;

  private volatile boolean sleep;

  @Before
  public void setUp() throws Exception {
    sleep = true;
  }

  @After
  public void tearDown() throws Exception {
    sleep = false;
  }

  /**
   * Test that we can get the value of a thread local from another thread.
   */
  @Test
  public void test() throws InterruptedException {
    final UnsafeThreadLocal<String> unsafeThreadLocal = new UnsafeThreadLocal<String>();
    final CountDownLatch localSet = new CountDownLatch(1);

    Thread test = new Thread() {
      public void run() {
        unsafeThreadLocal.set("hello");
        localSet.countDown();
        try {
          while (sleep) {
            Thread.sleep(INTERVAL);
          }
        } catch (InterruptedException e) {
          throw new AssertionError(e);
        }
      }
    };

    test.setDaemon(true);
    test.start();

    localSet.await();

    assertEquals("hello", unsafeThreadLocal.get(test));
    assertEquals(null, unsafeThreadLocal.get(Thread.currentThread()));
  }
}

==> apache-geode-1.7.0-src.zip: apache-geode-1.7.0-src/geode-core/src/test/java/org/apache/geode/distributed/internal/deadlock/UnsafeThreadLocalJUnitTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.distributed.internal.deadlock;

import static org.junit.Assert.assertEquals;

import java.util.concurrent.CountDownLatch;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;


public class UnsafeThreadLocalJUnitTest {

  private static final long INTERVAL = 10;

  private volatile boolean sleep;

  @Before
  public void setUp() throws Exception {
    sleep = true;
  }

  @After
  public void tearDown() throws Exception {
    sleep = false;
  }

  /**
   * Test that we can get the value of a thread local from another thread.
   */
  @Test
  public void test() throws InterruptedException {
    final UnsafeThreadLocal<String> unsafeThreadLocal = new UnsafeThreadLocal<String>();
    final CountDownLatch localSet = new CountDownLatch(1);

    Thread test = new Thread() {
      public void run() {
        unsafeThreadLocal.set("hello");
        localSet.countDown();
        try {
          while (sleep) {
            Thread.sleep(INTERVAL);
          }
        } catch (InterruptedException e) {
          throw new AssertionError(e);
        }
      }
    };

    test.setDaemon(true);
    test.start();

    localSet.await();

    assertEquals("hello", unsafeThreadLocal.get(test));
    assertEquals(null, unsafeThreadLocal.get(Thread.currentThread()));
  }
}
